class docommon::desktop (
  
  # class arguments
  # ---------------
  # setup defaults

  $user = 'web',
  $password = 'admLn**',
  $firewall = true,

  # end of class arguments
  # ----------------------
  # begin class

) {

  # expose firewall ports if requested
  if ($firewall) {
    @docommon::fireport { '05900 state NEW tcp dpt:5900':
      dport   => '5900',
      proto   => 'tcp',
    }

    @docommon::fireport { '05901 state NEW tcp dpt:5901':
      dport   => '5901',
      proto   => 'tcp',
    }
  }

  # OS-specific variants
  case $operatingsystem {
    centos, redhat, fedora: {
      # install desktop using groups (takes a long time)
      exec { 'install-desktop':
        command => '/usr/bin/yum install -y @basic-desktop @fonts @x11',
        timeout => 60*60,
        before => File['docommon-desktop-vnc-config'],
        require => Exec['up-to-date'],
      }

      # install VNC
      if ! defined(Package['tigervnc-server']) {
        package { 'tigervnc-server' :
          ensure => present,
          before => File['docommon-desktop-vnc-config'],
        }
      }
      if ! defined(Package['tigervnc']) {
        package { 'tigervnc' :
          ensure => present,
          before => File['docommon-desktop-vnc-config'],
        }
      }
      if ! defined(Package['xorg-x11-fonts-Type1']) {
        package { 'xorg-x11-fonts-Type1' :
          ensure => present,
          before => File['docommon-desktop-vnc-config'],
        }
      }
    
      # setup config file
      file { 'docommon-desktop-vnc-config' :
        path => '/etc/sysconfig/vncservers',
        content => template('docommon/vncserver.centos.erb'),
        mode => 0644,
        notify => Service['vncserver'],
        before => [Anchor['docommon-desktop-config']],
      }
    }
    ubuntu, debian: {
      # install desktop using tasksel groups
      package { ['ubuntu-desktop^']:
        require => Exec['up-to-date'],
        before => File['docommon-desktop-vnc-config'],
      }
      
      if ! defined(Package['tightvncserver']) {
        package { 'tightvncserver' :
          ensure => present,
          before => File['docommon-desktop-vnc-config'],
        }
      }
      if ! defined(Package['xfce4']) {
        package { 'xfce4' :
          ensure => present,
          before => File['docommon-desktop-vnc-config'],
        }
      }
      if ! defined(Package['xfce4-goodies']) {
        package { 'xfce4-goodies' :
          ensure => present,
          before => File['docommon-desktop-vnc-config'],
        }
      }

      # setup config file
      file { 'docommon-desktop-vnc-config' :
        path => '/etc/init.d/vncserver',
        content => template('docommon/vncserver.ubuntu.erb'),
        mode => 0644,
        notify => Service['vncserver'],
        before => [Anchor['docommon-desktop-config']],
      }
      
    }
  }

  anchor { 'docommon-desktop-config' : }

  file { 'docommon-desktop-vnc-makedir' :
    path => "/home/${user}/.vnc",
    ensure => 'directory',
    owner => $user,
    group => $user,
    mode => 0750,
  }->

  # set vncpasswd for main user
  exec { 'docommon-desktop-vnc-setpass' :
    path => '/usr/bin:/bin:/usr/sbin:/sbin',
    command => "echo ${password} | vncpasswd -f > /home/${user}/.vnc/passwd && chmod 600 /home/${user}/.vnc/passwd",
    user => $user,
    group => $user,
    notify => Service['vncserver'],
    creates => "/home/${user}/.vnc/passwd",
  }

  # start service (now and on restart)
  service { 'vncserver' :
    ensure => 'running',
    enable => 'true',
  }

}
